# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/std_msgs/msg/u_int8_multi_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import multi_array_layout_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_multi__array__layout__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/std_msgs/msg/u_int8_multi_array.proto\x12)make87_messages_ros2.rolling.std_msgs.msg\x1a\x42make87_messages_ros2/rolling/std_msgs/msg/multi_array_layout.proto\"l\n\x0fUInt8MultiArray\x12K\n\x06layout\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.rolling.std_msgs.msg.MultiArrayLayout\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.std_msgs.msg.u_int8_multi_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UINT8MULTIARRAY']._serialized_start=181
  _globals['_UINT8MULTIARRAY']._serialized_end=289
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetDomainConstantsRequest(_message.Message):
    __slots__ = ("type",)
    TYPE_FIELD_NUMBER: _ClassVar[int]
    type: str
    def __init__(self, type: _Optional[str] = ...) -> None: ...

class GetDomainConstantsResponse(_message.Message):
    __slots__ = ("success", "constants", "error_info")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    CONSTANTS_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    success: bool
    constants: _containers.RepeatedScalarFieldContainer[str]
    error_info: str
    def __init__(self, success: bool = ..., constants: _Optional[_Iterable[str]] = ..., error_info: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetRateRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetRateResponse(_message.Message):
    __slots__ = ("rate",)
    RATE_FIELD_NUMBER: _ClassVar[int]
    rate: float
    def __init__(self, rate: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/object_recognition_msgs/msg/recognized_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__stamped__pb2
from make87_messages_ros2.humble.object_recognition_msgs.msg import object_type_pb2 as make87__messages__ros2_dot_humble_dot_object__recognition__msgs_dot_msg_dot_object__type__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.humble.shape_msgs.msg import mesh_pb2 as make87__messages__ros2_dot_humble_dot_shape__msgs_dot_msg_dot_mesh__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/humble/object_recognition_msgs/msg/recognized_object.proto\x12\x37make87_messages_ros2.humble.object_recognition_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/point.proto\x1aPmake87_messages_ros2/humble/geometry_msgs/msg/pose_with_covariance_stamped.proto\x1aImake87_messages_ros2/humble/object_recognition_msgs/msg/object_type.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\x1a\x35make87_messages_ros2/humble/shape_msgs/msg/mesh.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xb0\x04\n\x10RecognizedObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12Q\n\x04type\x18\x03 \x01(\x0b\x32\x43.make87_messages_ros2.humble.object_recognition_msgs.msg.ObjectType\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12N\n\x0cpoint_clouds\x18\x05 \x03(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2\x12G\n\rbounding_mesh\x18\x06 \x01(\x0b\x32\x30.make87_messages_ros2.humble.shape_msgs.msg.Mesh\x12O\n\x11\x62ounding_contours\x18\x07 \x03(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12V\n\x04pose\x18\x08 \x01(\x0b\x32H.make87_messages_ros2.humble.geometry_msgs.msg.PoseWithCovarianceStampedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.object_recognition_msgs.msg.recognized_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RECOGNIZEDOBJECT']._serialized_start=566
  _globals['_RECOGNIZEDOBJECT']._serialized_end=1126
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MapMetaData(_message.Message):
    __slots__ = ("map_load_time", "resolution", "width", "height", "origin")
    MAP_LOAD_TIME_FIELD_NUMBER: _ClassVar[int]
    RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    map_load_time: _time_pb2.Time
    resolution: float
    width: int
    height: int
    origin: _pose_pb2.Pose
    def __init__(self, map_load_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., resolution: _Optional[float] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., origin: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.irobot_create_msgs.msg import audio_note_pb2 as _audio_note_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AudioNoteVector(_message.Message):
    __slots__ = ("header", "notes", "append")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NOTES_FIELD_NUMBER: _ClassVar[int]
    APPEND_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    notes: _containers.RepeatedCompositeFieldContainer[_audio_note_pb2.AudioNote]
    append: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., notes: _Optional[_Iterable[_Union[_audio_note_pb2.AudioNote, _Mapping]]] = ..., append: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nao_sensor_msgs/msg/buttons.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/nao_sensor_msgs/msg/buttons.proto\x12.make87_messages_ros2.jazzy.nao_sensor_msgs.msg\"\x8a\x01\n\x07\x42uttons\x12\r\n\x05\x63hest\x18\x01 \x01(\x08\x12\x1a\n\x12l_foot_bumper_left\x18\x02 \x01(\x08\x12\x1b\n\x13l_foot_bumper_right\x18\x03 \x01(\x08\x12\x1a\n\x12r_foot_bumper_left\x18\x04 \x01(\x08\x12\x1b\n\x13r_foot_bumper_right\x18\x05 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nao_sensor_msgs.msg.buttons_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BUTTONS']._serialized_start=113
  _globals['_BUTTONS']._serialized_end=251
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SuctionGrasp(_message.Message):
    __slots__ = ("uuid", "item_uuid", "pose", "quality", "max_suction_surface_length", "max_suction_surface_width")
    UUID_FIELD_NUMBER: _ClassVar[int]
    ITEM_UUID_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    QUALITY_FIELD_NUMBER: _ClassVar[int]
    MAX_SUCTION_SURFACE_LENGTH_FIELD_NUMBER: _ClassVar[int]
    MAX_SUCTION_SURFACE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    uuid: str
    item_uuid: str
    pose: _pose_stamped_pb2.PoseStamped
    quality: float
    max_suction_surface_length: float
    max_suction_surface_width: float
    def __init__(self, uuid: _Optional[str] = ..., item_uuid: _Optional[str] = ..., pose: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., quality: _Optional[float] = ..., max_suction_surface_length: _Optional[float] = ..., max_suction_surface_width: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marti_nav_msgs/msg/obstacle.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/marti_nav_msgs/msg/obstacle.proto\x12-make87_messages_ros2.jazzy.marti_nav_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"\x9e\x01\n\x08Obstacle\x12\n\n\x02id\x18\x01 \x01(\t\x12@\n\x04pose\x18\x02 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x44\n\x07polygon\x18\x03 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marti_nav_msgs.msg.obstacle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBSTACLE']._serialized_start=227
  _globals['_OBSTACLE']._serialized_end=385
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import esf_meas_data_item_pb2 as _esf_meas_data_item_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXEsfMeas(_message.Message):
    __slots__ = ("header", "time_tag", "time_mark_sent", "time_mark_edge", "calib_ttag_valid", "num_meas", "id", "data", "calib_ttag")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_TAG_FIELD_NUMBER: _ClassVar[int]
    TIME_MARK_SENT_FIELD_NUMBER: _ClassVar[int]
    TIME_MARK_EDGE_FIELD_NUMBER: _ClassVar[int]
    CALIB_TTAG_VALID_FIELD_NUMBER: _ClassVar[int]
    NUM_MEAS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    CALIB_TTAG_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_tag: int
    time_mark_sent: int
    time_mark_edge: bool
    calib_ttag_valid: bool
    num_meas: int
    id: int
    data: _containers.RepeatedCompositeFieldContainer[_esf_meas_data_item_pb2.ESFMeasDataItem]
    calib_ttag: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_tag: _Optional[int] = ..., time_mark_sent: _Optional[int] = ..., time_mark_edge: bool = ..., calib_ttag_valid: bool = ..., num_meas: _Optional[int] = ..., id: _Optional[int] = ..., data: _Optional[_Iterable[_Union[_esf_meas_data_item_pb2.ESFMeasDataItem, _Mapping]]] = ..., calib_ttag: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SrrStatus5(_message.Message):
    __slots__ = ("header", "ros2_header", "disable_auto_align", "can_tx_yaw_rate_ref_qf", "can_tx_yaw_rate_raw_qf", "can_tx_yaw_rate_reference", "can_tx_yaw_rate_raw", "can_tx_system_status", "can_tx_outside_temperature", "can_blockage_mnr_blocked", "can_blockage_bb_blocked", "can_blockage_radar_blocked", "can_td_blocked", "radar_tx_power_error", "radar_lo_power_error", "radar_data_sync_error", "linearizer_spi_transfer_error", "saturated_tuning_freq_error", "rtn_spi_transfer_error", "rrn_spi_transfer_error", "video_port_capture_error", "vertical_misalignment_error", "tx_temperature_fault", "transmitter_id_error", "dsp_unit_cal_checksum_error", "dsp_unit_cal_block_chcksm_error", "dsp_tuning_sensitivity_error", "dsp_loop_overrun_error", "adc_spi_transfer_error")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    DISABLE_AUTO_ALIGN_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_YAW_RATE_REF_QF_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_YAW_RATE_RAW_QF_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_YAW_RATE_REFERENCE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_YAW_RATE_RAW_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_SYSTEM_STATUS_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_OUTSIDE_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    CAN_BLOCKAGE_MNR_BLOCKED_FIELD_NUMBER: _ClassVar[int]
    CAN_BLOCKAGE_BB_BLOCKED_FIELD_NUMBER: _ClassVar[int]
    CAN_BLOCKAGE_RADAR_BLOCKED_FIELD_NUMBER: _ClassVar[int]
    CAN_TD_BLOCKED_FIELD_NUMBER: _ClassVar[int]
    RADAR_TX_POWER_ERROR_FIELD_NUMBER: _ClassVar[int]
    RADAR_LO_POWER_ERROR_FIELD_NUMBER: _ClassVar[int]
    RADAR_DATA_SYNC_ERROR_FIELD_NUMBER: _ClassVar[int]
    LINEARIZER_SPI_TRANSFER_ERROR_FIELD_NUMBER: _ClassVar[int]
    SATURATED_TUNING_FREQ_ERROR_FIELD_NUMBER: _ClassVar[int]
    RTN_SPI_TRANSFER_ERROR_FIELD_NUMBER: _ClassVar[int]
    RRN_SPI_TRANSFER_ERROR_FIELD_NUMBER: _ClassVar[int]
    VIDEO_PORT_CAPTURE_ERROR_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_MISALIGNMENT_ERROR_FIELD_NUMBER: _ClassVar[int]
    TX_TEMPERATURE_FAULT_FIELD_NUMBER: _ClassVar[int]
    TRANSMITTER_ID_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_UNIT_CAL_CHECKSUM_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_UNIT_CAL_BLOCK_CHCKSM_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_TUNING_SENSITIVITY_ERROR_FIELD_NUMBER: _ClassVar[int]
    DSP_LOOP_OVERRUN_ERROR_FIELD_NUMBER: _ClassVar[int]
    ADC_SPI_TRANSFER_ERROR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    disable_auto_align: bool
    can_tx_yaw_rate_ref_qf: int
    can_tx_yaw_rate_raw_qf: int
    can_tx_yaw_rate_reference: float
    can_tx_yaw_rate_raw: float
    can_tx_system_status: int
    can_tx_outside_temperature: int
    can_blockage_mnr_blocked: bool
    can_blockage_bb_blocked: bool
    can_blockage_radar_blocked: bool
    can_td_blocked: bool
    radar_tx_power_error: bool
    radar_lo_power_error: bool
    radar_data_sync_error: bool
    linearizer_spi_transfer_error: bool
    saturated_tuning_freq_error: bool
    rtn_spi_transfer_error: bool
    rrn_spi_transfer_error: bool
    video_port_capture_error: bool
    vertical_misalignment_error: bool
    tx_temperature_fault: bool
    transmitter_id_error: bool
    dsp_unit_cal_checksum_error: bool
    dsp_unit_cal_block_chcksm_error: bool
    dsp_tuning_sensitivity_error: bool
    dsp_loop_overrun_error: bool
    adc_spi_transfer_error: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., disable_auto_align: bool = ..., can_tx_yaw_rate_ref_qf: _Optional[int] = ..., can_tx_yaw_rate_raw_qf: _Optional[int] = ..., can_tx_yaw_rate_reference: _Optional[float] = ..., can_tx_yaw_rate_raw: _Optional[float] = ..., can_tx_system_status: _Optional[int] = ..., can_tx_outside_temperature: _Optional[int] = ..., can_blockage_mnr_blocked: bool = ..., can_blockage_bb_blocked: bool = ..., can_blockage_radar_blocked: bool = ..., can_td_blocked: bool = ..., radar_tx_power_error: bool = ..., radar_lo_power_error: bool = ..., radar_data_sync_error: bool = ..., linearizer_spi_transfer_error: bool = ..., saturated_tuning_freq_error: bool = ..., rtn_spi_transfer_error: bool = ..., rrn_spi_transfer_error: bool = ..., video_port_capture_error: bool = ..., vertical_misalignment_error: bool = ..., tx_temperature_fault: bool = ..., transmitter_id_error: bool = ..., dsp_unit_cal_checksum_error: bool = ..., dsp_unit_cal_block_chcksm_error: bool = ..., dsp_tuning_sensitivity_error: bool = ..., dsp_loop_overrun_error: bool = ..., adc_spi_transfer_error: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SBASSvData(_message.Message):
    __slots__ = ("svid", "reserved_1", "udre", "sv_sys", "sv_service", "reserved_2", "prc", "reserved_3", "ic")
    SVID_FIELD_NUMBER: _ClassVar[int]
    RESERVED_1_FIELD_NUMBER: _ClassVar[int]
    UDRE_FIELD_NUMBER: _ClassVar[int]
    SV_SYS_FIELD_NUMBER: _ClassVar[int]
    SV_SERVICE_FIELD_NUMBER: _ClassVar[int]
    RESERVED_2_FIELD_NUMBER: _ClassVar[int]
    PRC_FIELD_NUMBER: _ClassVar[int]
    RESERVED_3_FIELD_NUMBER: _ClassVar[int]
    IC_FIELD_NUMBER: _ClassVar[int]
    svid: int
    reserved_1: int
    udre: int
    sv_sys: int
    sv_service: int
    reserved_2: int
    prc: int
    reserved_3: _containers.RepeatedScalarFieldContainer[int]
    ic: int
    def __init__(self, svid: _Optional[int] = ..., reserved_1: _Optional[int] = ..., udre: _Optional[int] = ..., sv_sys: _Optional[int] = ..., sv_service: _Optional[int] = ..., reserved_2: _Optional[int] = ..., prc: _Optional[int] = ..., reserved_3: _Optional[_Iterable[int]] = ..., ic: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/micro_ros_diagnostic_msgs/srv/micro_ros_self_test.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.micro_ros_diagnostic_msgs.msg import micro_ros_diagnostic_status_pb2 as make87__messages__ros2_dot_humble_dot_micro__ros__diagnostic__msgs_dot_msg_dot_micro__ros__diagnostic__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSmake87_messages_ros2/humble/micro_ros_diagnostic_msgs/srv/micro_ros_self_test.proto\x12\x39make87_messages_ros2.humble.micro_ros_diagnostic_msgs.srv\x1a!make87_messages/core/header.proto\x1a[make87_messages_ros2/humble/micro_ros_diagnostic_msgs/msg/micro_ros_diagnostic_status.proto\"G\n\x17MicroROSSelfTestRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\"\xc9\x01\n\x18MicroROSSelfTestResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06passed\x18\x03 \x01(\r\x12\x63\n\x06status\x18\x04 \x01(\x0b\x32S.make87_messages_ros2.humble.micro_ros_diagnostic_msgs.msg.MicroROSDiagnosticStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.micro_ros_diagnostic_msgs.srv.micro_ros_self_test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MICROROSSELFTESTREQUEST']._serialized_start=274
  _globals['_MICROROSSELFTESTREQUEST']._serialized_end=345
  _globals['_MICROROSSELFTESTRESPONSE']._serialized_start=348
  _globals['_MICROROSSELFTESTRESPONSE']._serialized_end=549
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/vision_msgs/msg/pose2_d.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.vision_msgs.msg import point2_d_pb2 as make87__messages__ros2_dot_rolling_dot_vision__msgs_dot_msg_dot_point2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/vision_msgs/msg/pose2_d.proto\x12,make87_messages_ros2.rolling.vision_msgs.msg\x1a;make87_messages_ros2/rolling/vision_msgs/msg/point2_d.proto\"`\n\x06Pose2D\x12G\n\x08position\x18\x01 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.vision_msgs.msg.Point2D\x12\r\n\x05theta\x18\x02 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.vision_msgs.msg.pose2_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POSE2D']._serialized_start=169
  _globals['_POSE2D']._serialized_end=265
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ImusInfo(_message.Message):
    __slots__ = ("header", "sensor_ids", "battery_level", "temperature")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SENSOR_IDS_FIELD_NUMBER: _ClassVar[int]
    BATTERY_LEVEL_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    sensor_ids: _containers.RepeatedScalarFieldContainer[str]
    battery_level: float
    temperature: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., sensor_ids: _Optional[_Iterable[str]] = ..., battery_level: _Optional[float] = ..., temperature: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Network(_message.Message):
    __slots__ = ("header", "macattr", "essid", "channel", "rssi", "noise", "beacon")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MACATTR_FIELD_NUMBER: _ClassVar[int]
    ESSID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    RSSI_FIELD_NUMBER: _ClassVar[int]
    NOISE_FIELD_NUMBER: _ClassVar[int]
    BEACON_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    macattr: str
    essid: str
    channel: int
    rssi: int
    noise: int
    beacon: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., macattr: _Optional[str] = ..., essid: _Optional[str] = ..., channel: _Optional[int] = ..., rssi: _Optional[int] = ..., noise: _Optional[int] = ..., beacon: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.automotive_navigation_msgs.msg import lane_boundary_array_pb2 as _lane_boundary_array_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RoadNetworkBoundaries(_message.Message):
    __slots__ = ("header", "road_network_boundaries")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROAD_NETWORK_BOUNDARIES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    road_network_boundaries: _containers.RepeatedCompositeFieldContainer[_lane_boundary_array_pb2.LaneBoundaryArray]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., road_network_boundaries: _Optional[_Iterable[_Union[_lane_boundary_array_pb2.LaneBoundaryArray, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg import interference_indicator_pb2 as _interference_indicator_pb2
from make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg import misalignment_packet_pb2 as _misalignment_packet_pb2
from make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg import sensor_field_of_view_pb2 as _sensor_field_of_view_pb2
from make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg import sensor_modulation_performance_pb2 as _sensor_modulation_performance_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LocationAttributesPacket(_message.Message):
    __slots__ = ("header", "sensor_modulation_performance", "misalignment", "interference_indicator", "sensor_field_of_view")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SENSOR_MODULATION_PERFORMANCE_FIELD_NUMBER: _ClassVar[int]
    MISALIGNMENT_FIELD_NUMBER: _ClassVar[int]
    INTERFERENCE_INDICATOR_FIELD_NUMBER: _ClassVar[int]
    SENSOR_FIELD_OF_VIEW_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    sensor_modulation_performance: _sensor_modulation_performance_pb2.SensorModulationPerformance
    misalignment: _misalignment_packet_pb2.MisalignmentPacket
    interference_indicator: _interference_indicator_pb2.InterferenceIndicator
    sensor_field_of_view: _sensor_field_of_view_pb2.SensorFieldOfView
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., sensor_modulation_performance: _Optional[_Union[_sensor_modulation_performance_pb2.SensorModulationPerformance, _Mapping]] = ..., misalignment: _Optional[_Union[_misalignment_packet_pb2.MisalignmentPacket, _Mapping]] = ..., interference_indicator: _Optional[_Union[_interference_indicator_pb2.InterferenceIndicator, _Mapping]] = ..., sensor_field_of_view: _Optional[_Union[_sensor_field_of_view_pb2.SensorFieldOfView, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/kinematic_solver_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import joint_limits_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_joint__limits__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/moveit_msgs/msg/kinematic_solver_info.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a=make87_messages_ros2/jazzy/moveit_msgs/msg/joint_limits.proto\"\x87\x01\n\x13KinematicSolverInfo\x12\x13\n\x0bjoint_names\x18\x01 \x03(\t\x12G\n\x06limits\x18\x02 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.moveit_msgs.msg.JointLimits\x12\x12\n\nlink_names\x18\x03 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.kinematic_solver_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_KINEMATICSOLVERINFO']._serialized_start=182
  _globals['_KINEMATICSOLVERINFO']._serialized_end=317
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RobotMode(_message.Message):
    __slots__ = ("mode", "mode_request_id")
    MODE_FIELD_NUMBER: _ClassVar[int]
    MODE_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    mode: int
    mode_request_id: int
    def __init__(self, mode: _Optional[int] = ..., mode_request_id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/nao_lola_command_msgs/msg/left_eye_leds.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_color__rgba__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/nao_lola_command_msgs/msg/left_eye_leds.proto\x12\x34make87_messages_ros2.jazzy.nao_lola_command_msgs.msg\x1a\x38make87_messages_ros2/jazzy/std_msgs/msg/color_rgba.proto\"Q\n\x0bLeftEyeLeds\x12\x42\n\x06\x63olors\x18\x01 \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.std_msgs.msg.ColorRGBAb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.nao_lola_command_msgs.msg.left_eye_leds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LEFTEYELEDS']._serialized_start=188
  _globals['_LEFTEYELEDS']._serialized_end=269
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/gimbal_manager_pitchyaw.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/mavros_msgs/srv/gimbal_manager_pitchyaw.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"\x89\x01\n\x1cGimbalManagerPitchyawRequest\x12\r\n\x05pitch\x18\x01 \x01(\x02\x12\x0b\n\x03yaw\x18\x02 \x01(\x02\x12\x12\n\npitch_rate\x18\x03 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x04 \x01(\x02\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12\x18\n\x10gimbal_device_id\x18\x06 \x01(\r\"@\n\x1dGimbalManagerPitchyawResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.gimbal_manager_pitchyaw_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERPITCHYAWREQUEST']._serialized_start=125
  _globals['_GIMBALMANAGERPITCHYAWREQUEST']._serialized_end=262
  _globals['_GIMBALMANAGERPITCHYAWRESPONSE']._serialized_start=264
  _globals['_GIMBALMANAGERPITCHYAWRESPONSE']._serialized_end=328
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_perception_msgs/msg/traffic_signal.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.autoware_perception_msgs.msg import traffic_signal_element_pb2 as make87__messages__ros2_dot_humble_dot_autoware__perception__msgs_dot_msg_dot_traffic__signal__element__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/autoware_perception_msgs/msg/traffic_signal.proto\x12\x38make87_messages_ros2.humble.autoware_perception_msgs.msg\x1a!make87_messages/core/header.proto\x1aUmake87_messages_ros2/humble/autoware_perception_msgs/msg/traffic_signal_element.proto\"\xba\x01\n\rTrafficSignal\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x19\n\x11traffic_signal_id\x18\x02 \x01(\x03\x12`\n\x08\x65lements\x18\x03 \x03(\x0b\x32N.make87_messages_ros2.humble.autoware_perception_msgs.msg.TrafficSignalElementb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_perception_msgs.msg.traffic_signal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRAFFICSIGNAL']._serialized_start=262
  _globals['_TRAFFICSIGNAL']._serialized_end=448
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_descriptor_pb2 as _parameter_descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParameterEventDescriptors(_message.Message):
    __slots__ = ("new_parameters", "changed_parameters", "deleted_parameters")
    NEW_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    CHANGED_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    DELETED_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    new_parameters: _containers.RepeatedCompositeFieldContainer[_parameter_descriptor_pb2.ParameterDescriptor]
    changed_parameters: _containers.RepeatedCompositeFieldContainer[_parameter_descriptor_pb2.ParameterDescriptor]
    deleted_parameters: _containers.RepeatedCompositeFieldContainer[_parameter_descriptor_pb2.ParameterDescriptor]
    def __init__(self, new_parameters: _Optional[_Iterable[_Union[_parameter_descriptor_pb2.ParameterDescriptor, _Mapping]]] = ..., changed_parameters: _Optional[_Iterable[_Union[_parameter_descriptor_pb2.ParameterDescriptor, _Mapping]]] = ..., deleted_parameters: _Optional[_Iterable[_Union[_parameter_descriptor_pb2.ParameterDescriptor, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LkaLane(_message.Message):
    __slots__ = ("header", "ros2_header", "lane_type", "quality", "model_degree", "position_parameter_c0", "curvature_parameter_c2", "curvature_derivative_parameter_c3", "marking_width", "heading_angle_parameter_c1", "view_range", "view_range_availability")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    LANE_TYPE_FIELD_NUMBER: _ClassVar[int]
    QUALITY_FIELD_NUMBER: _ClassVar[int]
    MODEL_DEGREE_FIELD_NUMBER: _ClassVar[int]
    POSITION_PARAMETER_C0_FIELD_NUMBER: _ClassVar[int]
    CURVATURE_PARAMETER_C2_FIELD_NUMBER: _ClassVar[int]
    CURVATURE_DERIVATIVE_PARAMETER_C3_FIELD_NUMBER: _ClassVar[int]
    MARKING_WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEADING_ANGLE_PARAMETER_C1_FIELD_NUMBER: _ClassVar[int]
    VIEW_RANGE_FIELD_NUMBER: _ClassVar[int]
    VIEW_RANGE_AVAILABILITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    lane_type: int
    quality: int
    model_degree: int
    position_parameter_c0: float
    curvature_parameter_c2: float
    curvature_derivative_parameter_c3: float
    marking_width: float
    heading_angle_parameter_c1: float
    view_range: float
    view_range_availability: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., lane_type: _Optional[int] = ..., quality: _Optional[int] = ..., model_degree: _Optional[int] = ..., position_parameter_c0: _Optional[float] = ..., curvature_parameter_c2: _Optional[float] = ..., curvature_derivative_parameter_c3: _Optional[float] = ..., marking_width: _Optional[float] = ..., heading_angle_parameter_c1: _Optional[float] = ..., view_range: _Optional[float] = ..., view_range_availability: bool = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(_message.Message):
    __slots__ = ("header", "connected", "armed", "guided", "manual_input", "mode", "system_status")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_FIELD_NUMBER: _ClassVar[int]
    ARMED_FIELD_NUMBER: _ClassVar[int]
    GUIDED_FIELD_NUMBER: _ClassVar[int]
    MANUAL_INPUT_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    connected: bool
    armed: bool
    guided: bool
    manual_input: bool
    mode: str
    system_status: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., connected: bool = ..., armed: bool = ..., guided: bool = ..., manual_input: bool = ..., mode: _Optional[str] = ..., system_status: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ClientControlMode(_message.Message):
    __slots__ = ("header", "stamp", "visual_recording_state", "map_state", "localization_state", "recording_state", "alignment_state", "mask_state", "expandmap_state")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    VISUAL_RECORDING_STATE_FIELD_NUMBER: _ClassVar[int]
    MAP_STATE_FIELD_NUMBER: _ClassVar[int]
    LOCALIZATION_STATE_FIELD_NUMBER: _ClassVar[int]
    RECORDING_STATE_FIELD_NUMBER: _ClassVar[int]
    ALIGNMENT_STATE_FIELD_NUMBER: _ClassVar[int]
    MASK_STATE_FIELD_NUMBER: _ClassVar[int]
    EXPANDMAP_STATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    stamp: _time_pb2.Time
    visual_recording_state: int
    map_state: int
    localization_state: int
    recording_state: int
    alignment_state: int
    mask_state: int
    expandmap_state: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., visual_recording_state: _Optional[int] = ..., map_state: _Optional[int] = ..., localization_state: _Optional[int] = ..., recording_state: _Optional[int] = ..., alignment_state: _Optional[int] = ..., mask_state: _Optional[int] = ..., expandmap_state: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.sbg_driver.msg import sbg_air_data_status_pb2 as _sbg_air_data_status_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgAirData(_message.Message):
    __slots__ = ("header", "time_stamp", "status", "pressure_abs", "altitude", "pressure_diff", "true_air_speed", "air_temperature")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PRESSURE_ABS_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    PRESSURE_DIFF_FIELD_NUMBER: _ClassVar[int]
    TRUE_AIR_SPEED_FIELD_NUMBER: _ClassVar[int]
    AIR_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_stamp: int
    status: _sbg_air_data_status_pb2.SbgAirDataStatus
    pressure_abs: float
    altitude: float
    pressure_diff: float
    true_air_speed: float
    air_temperature: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., status: _Optional[_Union[_sbg_air_data_status_pb2.SbgAirDataStatus, _Mapping]] = ..., pressure_abs: _Optional[float] = ..., altitude: _Optional[float] = ..., pressure_diff: _Optional[float] = ..., true_air_speed: _Optional[float] = ..., air_temperature: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/kartech_linear_actuator_msgs/msg/enhanced_position_rpt.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/jazzy/kartech_linear_actuator_msgs/msg/enhanced_position_rpt.proto\x12;make87_messages_ros2.jazzy.kartech_linear_actuator_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xe4\x02\n\x13\x45nhancedPositionRpt\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x17\n\x0fshaft_extension\x18\x02 \x01(\x01\x12\x1c\n\x14motor_overload_error\x18\x03 \x01(\x08\x12\x1d\n\x15\x63lutch_overload_error\x18\x04 \x01(\x08\x12\x1d\n\x15motor_open_load_error\x18\x05 \x01(\x08\x12\x1e\n\x16\x63lutch_open_load_error\x18\x06 \x01(\x08\x12\x1c\n\x14position_reach_error\x18\x07 \x01(\x08\x12 \n\x18hardware_warning_1_error\x18\x08 \x01(\x08\x12 \n\x18hardware_warning_2_error\x18\t \x01(\x08\x12\x15\n\rmotor_current\x18\n \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.kartech_linear_actuator_msgs.msg.enhanced_position_rpt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ENHANCEDPOSITIONRPT']._serialized_start=207
  _globals['_ENHANCEDPOSITIONRPT']._serialized_end=563
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_stamped_pb2 as _vector3_stamped_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GripperTranslation(_message.Message):
    __slots__ = ("direction", "desired_distance", "min_distance")
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    DESIRED_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    MIN_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    direction: _vector3_stamped_pb2.Vector3Stamped
    desired_distance: float
    min_distance: float
    def __init__(self, direction: _Optional[_Union[_vector3_stamped_pb2.Vector3Stamped, _Mapping]] = ..., desired_distance: _Optional[float] = ..., min_distance: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import multi_dof_joint_trajectory_point_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_multi__dof__joint__trajectory__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory.proto\x12.make87_messages_ros2.jazzy.trajectory_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1aUmake87_messages_ros2/jazzy/trajectory_msgs/msg/multi_dof_joint_trajectory_point.proto\"\xcd\x01\n\x17MultiDOFJointTrajectory\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x13\n\x0bjoint_names\x18\x02 \x03(\t\x12\\\n\x06points\x18\x03 \x03(\x0b\x32L.make87_messages_ros2.jazzy.trajectory_msgs.msg.MultiDOFJointTrajectoryPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.trajectory_msgs.msg.multi_dof_joint_trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MULTIDOFJOINTTRAJECTORY']._serialized_start=273
  _globals['_MULTIDOFJOINTTRAJECTORY']._serialized_end=478
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.flexbe_msgs.msg import userdata_info_pb2 as _userdata_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetUserdataRequest(_message.Message):
    __slots__ = ("userdata_key",)
    USERDATA_KEY_FIELD_NUMBER: _ClassVar[int]
    userdata_key: str
    def __init__(self, userdata_key: _Optional[str] = ...) -> None: ...

class GetUserdataResponse(_message.Message):
    __slots__ = ("success", "message", "userdata")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    USERDATA_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    userdata: _containers.RepeatedCompositeFieldContainer[_userdata_info_pb2.UserdataInfo]
    def __init__(self, success: bool = ..., message: _Optional[str] = ..., userdata: _Optional[_Iterable[_Union[_userdata_info_pb2.UserdataInfo, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CancelTriggerRequest(_message.Message):
    __slots__ = ("header", "name")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ...) -> None: ...

class CancelTriggerResponse(_message.Message):
    __slots__ = ("header", "success", "message")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    message: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., message: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.cartographer_ros_msgs.msg import status_response_pb2 as _status_response_pb2
from make87_messages_ros2.rolling.cartographer_ros_msgs.msg import submap_texture_pb2 as _submap_texture_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmapQueryRequest(_message.Message):
    __slots__ = ("trajectory_id", "submap_index")
    TRAJECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMAP_INDEX_FIELD_NUMBER: _ClassVar[int]
    trajectory_id: int
    submap_index: int
    def __init__(self, trajectory_id: _Optional[int] = ..., submap_index: _Optional[int] = ...) -> None: ...

class SubmapQueryResponse(_message.Message):
    __slots__ = ("status", "submap_version", "textures")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBMAP_VERSION_FIELD_NUMBER: _ClassVar[int]
    TEXTURES_FIELD_NUMBER: _ClassVar[int]
    status: _status_response_pb2.StatusResponse
    submap_version: int
    textures: _containers.RepeatedCompositeFieldContainer[_submap_texture_pb2.SubmapTexture]
    def __init__(self, status: _Optional[_Union[_status_response_pb2.StatusResponse, _Mapping]] = ..., submap_version: _Optional[int] = ..., textures: _Optional[_Iterable[_Union[_submap_texture_pb2.SubmapTexture, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ReadSplitEvent(_message.Message):
    __slots__ = ("closed_file", "opened_file", "node_name")
    CLOSED_FILE_FIELD_NUMBER: _ClassVar[int]
    OPENED_FILE_FIELD_NUMBER: _ClassVar[int]
    NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    closed_file: str
    opened_file: str
    node_name: str
    def __init__(self, closed_file: _Optional[str] = ..., opened_file: _Optional[str] = ..., node_name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/r2r_spl_test_interfaces/msg/basic_types.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/r2r_spl_test_interfaces/msg/basic_types.proto\x12\x37make87_messages_ros2.humble.r2r_spl_test_interfaces.msg\x1a!make87_messages/core/header.proto\"\xb4\x02\n\nBasicTypes\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08val_bool\x18\x02 \x01(\x08\x12\x10\n\x08val_byte\x18\x03 \x01(\r\x12\x10\n\x08val_char\x18\x04 \x01(\x05\x12\x13\n\x0bval_float32\x18\x05 \x01(\x02\x12\x13\n\x0bval_float64\x18\x06 \x01(\x01\x12\x10\n\x08val_int8\x18\x07 \x01(\x05\x12\x11\n\tval_uint8\x18\x08 \x01(\r\x12\x11\n\tval_int16\x18\t \x01(\x05\x12\x12\n\nval_uint16\x18\n \x01(\r\x12\x11\n\tval_int32\x18\x0b \x01(\x05\x12\x12\n\nval_uint32\x18\x0c \x01(\r\x12\x11\n\tval_int64\x18\r \x01(\x03\x12\x12\n\nval_uint64\x18\x0e \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.r2r_spl_test_interfaces.msg.basic_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BASICTYPES']._serialized_start=170
  _globals['_BASICTYPES']._serialized_end=478
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import load_carrier_pb2 as _load_carrier_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DetectLoadCarriersRequest(_message.Message):
    __slots__ = ("pose_frame", "region_of_interest_id", "region_of_interest_2d_id", "load_carrier_ids", "robot_pose")
    POSE_FRAME_FIELD_NUMBER: _ClassVar[int]
    REGION_OF_INTEREST_ID_FIELD_NUMBER: _ClassVar[int]
    REGION_OF_INTEREST_2D_ID_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIER_IDS_FIELD_NUMBER: _ClassVar[int]
    ROBOT_POSE_FIELD_NUMBER: _ClassVar[int]
    pose_frame: str
    region_of_interest_id: str
    region_of_interest_2d_id: str
    load_carrier_ids: _containers.RepeatedScalarFieldContainer[str]
    robot_pose: _pose_pb2.Pose
    def __init__(self, pose_frame: _Optional[str] = ..., region_of_interest_id: _Optional[str] = ..., region_of_interest_2d_id: _Optional[str] = ..., load_carrier_ids: _Optional[_Iterable[str]] = ..., robot_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...

class DetectLoadCarriersResponse(_message.Message):
    __slots__ = ("timestamp", "load_carriers", "return_code")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIERS_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    timestamp: _time_pb2.Time
    load_carriers: _containers.RepeatedCompositeFieldContainer[_load_carrier_pb2.LoadCarrier]
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., load_carriers: _Optional[_Iterable[_Union[_load_carrier_pb2.LoadCarrier, _Mapping]]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/lgsvl_msgs/msg/detected_radar_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/lgsvl_msgs/msg/detected_radar_object.proto\x12*make87_messages_ros2.humble.lgsvl_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/geometry_msgs/msg/point.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\"\xf4\x06\n\x13\x44\x65tectedRadarObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\x05\x12J\n\nsensor_aim\x18\x03 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12L\n\x0csensor_right\x18\x04 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12M\n\x0fsensor_position\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12O\n\x0fsensor_velocity\x18\x06 \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\x14\n\x0csensor_angle\x18\x07 \x01(\x01\x12M\n\x0fobject_position\x18\x08 \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12O\n\x0fobject_velocity\x18\t \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12V\n\x18object_relative_position\x18\n \x01(\x0b\x32\x34.make87_messages_ros2.humble.geometry_msgs.msg.Point\x12X\n\x18object_relative_velocity\x18\x0b \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12T\n\x14object_collider_size\x18\x0c \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\x14\n\x0cobject_state\x18\r \x01(\r\x12\x15\n\rnew_detection\x18\x0e \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.lgsvl_msgs.msg.detected_radar_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTEDRADAROBJECT']._serialized_start=274
  _globals['_DETECTEDRADAROBJECT']._serialized_end=1158
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NavPOSECEF(_message.Message):
    __slots__ = ("i_tow", "ecef_x", "ecef_y", "ecef_z", "p_acc")
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    ECEF_X_FIELD_NUMBER: _ClassVar[int]
    ECEF_Y_FIELD_NUMBER: _ClassVar[int]
    ECEF_Z_FIELD_NUMBER: _ClassVar[int]
    P_ACC_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    ecef_x: int
    ecef_y: int
    ecef_z: int
    p_acc: int
    def __init__(self, i_tow: _Optional[int] = ..., ecef_x: _Optional[int] = ..., ecef_y: _Optional[int] = ..., ecef_z: _Optional[int] = ..., p_acc: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/diagnostic_msgs/msg/diagnostic_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.diagnostic_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_jazzy_dot_diagnostic__msgs_dot_msg_dot_key__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/jazzy/diagnostic_msgs/msg/diagnostic_status.proto\x12.make87_messages_ros2.jazzy.diagnostic_msgs.msg\x1a>make87_messages_ros2/jazzy/diagnostic_msgs/msg/key_value.proto\"\x9f\x01\n\x10\x44iagnosticStatus\x12\r\n\x05level\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x13\n\x0bhardware_id\x18\x04 \x01(\t\x12H\n\x06values\x18\x05 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.diagnostic_msgs.msg.KeyValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.diagnostic_msgs.msg.diagnostic_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DIAGNOSTICSTATUS']._serialized_start=187
  _globals['_DIAGNOSTICSTATUS']._serialized_end=346
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/behaviour_tree.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.diagnostic_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_jazzy_dot_diagnostic__msgs_dot_msg_dot_key__value__pb2
from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import activity_item_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_activity__item__pb2
from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import behaviour_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_behaviour__pb2
from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import statistics_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_statistics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/behaviour_tree.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg\x1a>make87_messages_ros2/jazzy/diagnostic_msgs/msg/key_value.proto\x1aJmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/activity_item.proto\x1a\x46make87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/behaviour.proto\x1aGmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/statistics.proto\"\x90\x03\n\rBehaviourTree\x12U\n\nbehaviours\x18\x01 \x03(\x0b\x32\x41.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.Behaviour\x12\x0f\n\x07\x63hanged\x18\x02 \x01(\x08\x12\\\n\x1a\x62lackboard_on_visited_path\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.diagnostic_msgs.msg.KeyValue\x12\x61\n\x13\x62lackboard_activity\x18\x04 \x03(\x0b\x32\x44.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.ActivityItem\x12V\n\nstatistics\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.Statisticsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.behaviour_tree_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BEHAVIOURTREE']._serialized_start=421
  _globals['_BEHAVIOURTREE']._serialized_end=821
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrackedFeature(_message.Message):
    __slots__ = ("header", "ros2_header", "position", "id", "age", "harris_score", "tracking_error")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    HARRIS_SCORE_FIELD_NUMBER: _ClassVar[int]
    TRACKING_ERROR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    position: _point_pb2.Point
    id: int
    age: int
    harris_score: float
    tracking_error: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., id: _Optional[int] = ..., age: _Optional[int] = ..., harris_score: _Optional[float] = ..., tracking_error: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PositionTarget(_message.Message):
    __slots__ = ("header", "ros2_header", "coordinate_frame", "type_mask", "position", "velocity", "acceleration_or_force", "yaw", "yaw_rate")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    COORDINATE_FRAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_MASK_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_OR_FORCE_FIELD_NUMBER: _ClassVar[int]
    YAW_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    coordinate_frame: int
    type_mask: int
    position: _point_pb2.Point
    velocity: _vector3_pb2.Vector3
    acceleration_or_force: _vector3_pb2.Vector3
    yaw: float
    yaw_rate: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., coordinate_frame: _Optional[int] = ..., type_mask: _Optional[int] = ..., position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., velocity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., acceleration_or_force: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., yaw: _Optional[float] = ..., yaw_rate: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_query_participants_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__participants__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import schedule_query_spacetime_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__spacetime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query.proto\x12\x30make87_messages_ros2.humble.rmf_traffic_msgs.msg\x1a!make87_messages/core/header.proto\x1aRmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query_participants.proto\x1aOmake87_messages_ros2/humble/rmf_traffic_msgs/msg/schedule_query_spacetime.proto\"\xfd\x01\n\rScheduleQuery\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12[\n\tspacetime\x18\x02 \x01(\x0b\x32H.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleQuerySpacetime\x12\x61\n\x0cparticipants\x18\x03 \x01(\x0b\x32K.make87_messages_ros2.humble.rmf_traffic_msgs.msg.ScheduleQueryParticipantsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_traffic_msgs.msg.schedule_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SCHEDULEQUERY']._serialized_start=324
  _globals['_SCHEDULEQUERY']._serialized_end=577
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.flexbe_msgs.msg import container_pb2 as _container_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BehaviorRequest(_message.Message):
    __slots__ = ("behavior_name", "autonomy_level", "arg_keys", "arg_values", "structure")
    BEHAVIOR_NAME_FIELD_NUMBER: _ClassVar[int]
    AUTONOMY_LEVEL_FIELD_NUMBER: _ClassVar[int]
    ARG_KEYS_FIELD_NUMBER: _ClassVar[int]
    ARG_VALUES_FIELD_NUMBER: _ClassVar[int]
    STRUCTURE_FIELD_NUMBER: _ClassVar[int]
    behavior_name: str
    autonomy_level: int
    arg_keys: _containers.RepeatedScalarFieldContainer[str]
    arg_values: _containers.RepeatedScalarFieldContainer[str]
    structure: _containers.RepeatedCompositeFieldContainer[_container_pb2.Container]
    def __init__(self, behavior_name: _Optional[str] = ..., autonomy_level: _Optional[int] = ..., arg_keys: _Optional[_Iterable[str]] = ..., arg_values: _Optional[_Iterable[str]] = ..., structure: _Optional[_Iterable[_Union[_container_pb2.Container, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.controller_manager_msgs.msg import controller_state_pb2 as _controller_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListControllersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListControllersResponse(_message.Message):
    __slots__ = ("controller",)
    CONTROLLER_FIELD_NUMBER: _ClassVar[int]
    controller: _containers.RepeatedCompositeFieldContainer[_controller_state_pb2.ControllerState]
    def __init__(self, controller: _Optional[_Iterable[_Union[_controller_state_pb2.ControllerState, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/object2271.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ibeo_msgs.msg import tracked_properties_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_tracked__properties__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import untracked_properties_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_untracked__properties__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/ibeo_msgs/msg/object2271.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a\x43make87_messages_ros2/rolling/ibeo_msgs/msg/tracked_properties.proto\x1a\x45make87_messages_ros2/rolling/ibeo_msgs/msg/untracked_properties.proto\"\xa0\x02\n\nObject2271\x12\n\n\x02id\x18\x01 \x01(\r\x12$\n\x1ctracked_properties_available\x18\x02 \x01(\x08\x12&\n\x1euntracked_properties_available\x18\x03 \x01(\x08\x12Y\n\x12tracked_properties\x18\x04 \x01(\x0b\x32=.make87_messages_ros2.rolling.ibeo_msgs.msg.TrackedProperties\x12]\n\x14untracked_properties\x18\x05 \x01(\x0b\x32?.make87_messages_ros2.rolling.ibeo_msgs.msg.UntrackedPropertiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.object2271_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBJECT2271']._serialized_start=248
  _globals['_OBJECT2271']._serialized_end=536
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WheelStates(_message.Message):
    __slots__ = ("stamp", "position", "velocity", "torque", "pwm_duty_cycle")
    STAMP_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    TORQUE_FIELD_NUMBER: _ClassVar[int]
    PWM_DUTY_CYCLE_FIELD_NUMBER: _ClassVar[int]
    stamp: _time_pb2.Time
    position: _containers.RepeatedScalarFieldContainer[float]
    velocity: _containers.RepeatedScalarFieldContainer[float]
    torque: _containers.RepeatedScalarFieldContainer[float]
    pwm_duty_cycle: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., position: _Optional[_Iterable[float]] = ..., velocity: _Optional[_Iterable[float]] = ..., torque: _Optional[_Iterable[float]] = ..., pwm_duty_cycle: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MrrHeaderSensorCoverage(_message.Message):
    __slots__ = ("header", "can_sensor_fov_hor", "can_doppler_coverage", "can_range_coverage")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_SENSOR_FOV_HOR_FIELD_NUMBER: _ClassVar[int]
    CAN_DOPPLER_COVERAGE_FIELD_NUMBER: _ClassVar[int]
    CAN_RANGE_COVERAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_sensor_fov_hor: int
    can_doppler_coverage: int
    can_range_coverage: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_sensor_fov_hor: _Optional[int] = ..., can_doppler_coverage: _Optional[int] = ..., can_range_coverage: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/example_interfaces/msg/u_int64_multi_array.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.example_interfaces.msg import multi_array_layout_pb2 as make87__messages__ros2_dot_humble_dot_example__interfaces_dot_msg_dot_multi__array__layout__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/humble/example_interfaces/msg/u_int64_multi_array.proto\x12\x32make87_messages_ros2.humble.example_interfaces.msg\x1a!make87_messages/core/header.proto\x1aKmake87_messages_ros2/humble/example_interfaces/msg/multi_array_layout.proto\"\xa4\x01\n\x10UInt64MultiArray\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12T\n\x06layout\x18\x02 \x01(\x0b\x32\x44.make87_messages_ros2.humble.example_interfaces.msg.MultiArrayLayout\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.example_interfaces.msg.u_int64_multi_array_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UINT64MULTIARRAY']._serialized_start=245
  _globals['_UINT64MULTIARRAY']._serialized_end=409
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as _point_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PointWithCovariance(_message.Message):
    __slots__ = ("point", "covariance")
    POINT_FIELD_NUMBER: _ClassVar[int]
    COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    point: _point_pb2.Point
    covariance: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, point: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., covariance: _Optional[_Iterable[float]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class OutcomeCondition(_message.Message):
    __slots__ = ("state_name", "state_outcome")
    STATE_NAME_FIELD_NUMBER: _ClassVar[int]
    STATE_OUTCOME_FIELD_NUMBER: _ClassVar[int]
    state_name: _containers.RepeatedScalarFieldContainer[str]
    state_outcome: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, state_name: _Optional[_Iterable[str]] = ..., state_outcome: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BlockadeCheckpoint(_message.Message):
    __slots__ = ("position", "map_name", "can_hold")
    POSITION_FIELD_NUMBER: _ClassVar[int]
    MAP_NAME_FIELD_NUMBER: _ClassVar[int]
    CAN_HOLD_FIELD_NUMBER: _ClassVar[int]
    position: _containers.RepeatedScalarFieldContainer[float]
    map_name: str
    can_hold: bool
    def __init__(self, position: _Optional[_Iterable[float]] = ..., map_name: _Optional[str] = ..., can_hold: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NamedCollision(_message.Message):
    __slots__ = ("header", "entity0", "entity1")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ENTITY0_FIELD_NUMBER: _ClassVar[int]
    ENTITY1_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    entity0: str
    entity1: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., entity0: _Optional[str] = ..., entity1: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/automotive_platform_msgs/msg/user_input_media.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/automotive_platform_msgs/msg/user_input_media.proto\x12\x39make87_messages_ros2.rolling.automotive_platform_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xde\x02\n\x0eUserInputMedia\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x12\n\nbtn_vol_up\x18\x02 \x01(\x08\x12\x14\n\x0c\x62tn_vol_down\x18\x03 \x01(\x08\x12\x10\n\x08\x62tn_mute\x18\x04 \x01(\x08\x12\x10\n\x08\x62tn_next\x18\x05 \x01(\x08\x12\x10\n\x08\x62tn_prev\x18\x06 \x01(\x08\x12\x18\n\x10\x62tn_next_hang_up\x18\x07 \x01(\x08\x12\x17\n\x0f\x62tn_prev_answer\x18\x08 \x01(\x08\x12\x13\n\x0b\x62tn_hang_up\x18\t \x01(\x08\x12\x12\n\nbtn_answer\x18\n \x01(\x08\x12\x10\n\x08\x62tn_play\x18\x0b \x01(\x08\x12\x11\n\tbtn_pause\x18\x0c \x01(\x08\x12\x16\n\x0e\x62tn_play_pause\x18\r \x01(\x08\x12\x10\n\x08\x62tn_mode\x18\x0e \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.automotive_platform_msgs.msg.user_input_media_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_USERINPUTMEDIA']._serialized_start=200
  _globals['_USERINPUTMEDIA']._serialized_end=550
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SonarImageData(_message.Message):
    __slots__ = ("is_bigendian", "dtype", "beam_count", "data")
    IS_BIGENDIAN_FIELD_NUMBER: _ClassVar[int]
    DTYPE_FIELD_NUMBER: _ClassVar[int]
    BEAM_COUNT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    is_bigendian: bool
    dtype: int
    beam_count: int
    data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, is_bigendian: bool = ..., dtype: _Optional[int] = ..., beam_count: _Optional[int] = ..., data: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/radar_msgs/msg/radar_track.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_jazzy_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/jazzy/radar_msgs/msg/radar_track.proto\x12)make87_messages_ros2.jazzy.radar_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a:make87_messages_ros2/jazzy/geometry_msgs/msg/vector3.proto\x1a@make87_messages_ros2/jazzy/unique_identifier_msgs/msg/uuid.proto\"\x85\x04\n\nRadarTrack\x12I\n\x04uuid\x18\x01 \x01(\x0b\x32;.make87_messages_ros2.jazzy.unique_identifier_msgs.msg.UUID\x12\x45\n\x08position\x18\x02 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12G\n\x08velocity\x18\x03 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12K\n\x0c\x61\x63\x63\x65leration\x18\x04 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12\x43\n\x04size\x18\x05 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.geometry_msgs.msg.Vector3\x12\x16\n\x0e\x63lassification\x18\x06 \x01(\r\x12\x1b\n\x13position_covariance\x18\x07 \x03(\x02\x12\x1b\n\x13velocity_covariance\x18\x08 \x03(\x02\x12\x1f\n\x17\x61\x63\x63\x65leration_covariance\x18\t \x03(\x02\x12\x17\n\x0fsize_covariance\x18\n \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.radar_msgs.msg.radar_track_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RADARTRACK']._serialized_start=291
  _globals['_RADARTRACK']._serialized_end=808
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RequestVoteRequest(_message.Message):
    __slots__ = ("header", "term", "candidate_id", "last_data_index", "loat_data_term")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TERM_FIELD_NUMBER: _ClassVar[int]
    CANDIDATE_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_DATA_INDEX_FIELD_NUMBER: _ClassVar[int]
    LOAT_DATA_TERM_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    term: int
    candidate_id: int
    last_data_index: int
    loat_data_term: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., term: _Optional[int] = ..., candidate_id: _Optional[int] = ..., last_data_index: _Optional[int] = ..., loat_data_term: _Optional[int] = ...) -> None: ...

class RequestVoteResponse(_message.Message):
    __slots__ = ("header", "term", "vote_granted")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TERM_FIELD_NUMBER: _ClassVar[int]
    VOTE_GRANTED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    term: int
    vote_granted: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., term: _Optional[int] = ..., vote_granted: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FSR(_message.Message):
    __slots__ = ("l_foot_front_left", "l_foot_front_right", "l_foot_back_left", "l_foot_back_right", "r_foot_front_left", "r_foot_front_right", "r_foot_back_left", "r_foot_back_right")
    L_FOOT_FRONT_LEFT_FIELD_NUMBER: _ClassVar[int]
    L_FOOT_FRONT_RIGHT_FIELD_NUMBER: _ClassVar[int]
    L_FOOT_BACK_LEFT_FIELD_NUMBER: _ClassVar[int]
    L_FOOT_BACK_RIGHT_FIELD_NUMBER: _ClassVar[int]
    R_FOOT_FRONT_LEFT_FIELD_NUMBER: _ClassVar[int]
    R_FOOT_FRONT_RIGHT_FIELD_NUMBER: _ClassVar[int]
    R_FOOT_BACK_LEFT_FIELD_NUMBER: _ClassVar[int]
    R_FOOT_BACK_RIGHT_FIELD_NUMBER: _ClassVar[int]
    l_foot_front_left: float
    l_foot_front_right: float
    l_foot_back_left: float
    l_foot_back_right: float
    r_foot_front_left: float
    r_foot_front_right: float
    r_foot_back_left: float
    r_foot_back_right: float
    def __init__(self, l_foot_front_left: _Optional[float] = ..., l_foot_front_right: _Optional[float] = ..., l_foot_back_left: _Optional[float] = ..., l_foot_back_right: _Optional[float] = ..., r_foot_front_left: _Optional[float] = ..., r_foot_front_right: _Optional[float] = ..., r_foot_back_left: _Optional[float] = ..., r_foot_back_right: _Optional[float] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ClosedLanes(_message.Message):
    __slots__ = ("fleet_name", "closed_lanes")
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    CLOSED_LANES_FIELD_NUMBER: _ClassVar[int]
    fleet_name: str
    closed_lanes: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, fleet_name: _Optional[str] = ..., closed_lanes: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.rolling.moveit_msgs.msg import planner_params_pb2 as _planner_params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetPlannerParamsRequest(_message.Message):
    __slots__ = ("pipeline_id", "planner_config", "group", "params", "replace")
    PIPELINE_ID_FIELD_NUMBER: _ClassVar[int]
    PLANNER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    REPLACE_FIELD_NUMBER: _ClassVar[int]
    pipeline_id: str
    planner_config: str
    group: str
    params: _planner_params_pb2.PlannerParams
    replace: bool
    def __init__(self, pipeline_id: _Optional[str] = ..., planner_config: _Optional[str] = ..., group: _Optional[str] = ..., params: _Optional[_Union[_planner_params_pb2.PlannerParams, _Mapping]] = ..., replace: bool = ...) -> None: ...

class SetPlannerParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/constraints.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import joint_constraint_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_joint__constraint__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import orientation_constraint_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_orientation__constraint__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import position_constraint_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_position__constraint__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import visibility_constraint_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_visibility__constraint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/rolling/moveit_msgs/msg/constraints.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x43make87_messages_ros2/rolling/moveit_msgs/msg/joint_constraint.proto\x1aImake87_messages_ros2/rolling/moveit_msgs/msg/orientation_constraint.proto\x1a\x46make87_messages_ros2/rolling/moveit_msgs/msg/position_constraint.proto\x1aHmake87_messages_ros2/rolling/moveit_msgs/msg/visibility_constraint.proto\"\x9f\x03\n\x0b\x43onstraints\x12\x0c\n\x04name\x18\x01 \x01(\t\x12X\n\x11joint_constraints\x18\x02 \x03(\x0b\x32=.make87_messages_ros2.rolling.moveit_msgs.msg.JointConstraint\x12^\n\x14position_constraints\x18\x03 \x03(\x0b\x32@.make87_messages_ros2.rolling.moveit_msgs.msg.PositionConstraint\x12\x64\n\x17orientation_constraints\x18\x04 \x03(\x0b\x32\x43.make87_messages_ros2.rolling.moveit_msgs.msg.OrientationConstraint\x12\x62\n\x16visibility_constraints\x18\x05 \x03(\x0b\x32\x42.make87_messages_ros2.rolling.moveit_msgs.msg.VisibilityConstraintb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.constraints_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONSTRAINTS']._serialized_start=403
  _globals['_CONSTRAINTS']._serialized_end=818
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavCov(_message.Message):
    __slots__ = ("header", "ros2_header", "itow", "version", "pos_cor_valid", "vel_cor_valid", "pos_cov_nn", "pos_cov_ne", "pos_cov_nd", "pos_cov_ee", "pos_cov_ed", "pos_cov_dd", "vel_cov_nn", "vel_cov_ne", "vel_cov_nd", "vel_cov_ee", "vel_cov_ed", "vel_cov_dd")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    POS_COR_VALID_FIELD_NUMBER: _ClassVar[int]
    VEL_COR_VALID_FIELD_NUMBER: _ClassVar[int]
    POS_COV_NN_FIELD_NUMBER: _ClassVar[int]
    POS_COV_NE_FIELD_NUMBER: _ClassVar[int]
    POS_COV_ND_FIELD_NUMBER: _ClassVar[int]
    POS_COV_EE_FIELD_NUMBER: _ClassVar[int]
    POS_COV_ED_FIELD_NUMBER: _ClassVar[int]
    POS_COV_DD_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_NN_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_NE_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_ND_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_EE_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_ED_FIELD_NUMBER: _ClassVar[int]
    VEL_COV_DD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    itow: int
    version: int
    pos_cor_valid: bool
    vel_cor_valid: bool
    pos_cov_nn: float
    pos_cov_ne: float
    pos_cov_nd: float
    pos_cov_ee: float
    pos_cov_ed: float
    pos_cov_dd: float
    vel_cov_nn: float
    vel_cov_ne: float
    vel_cov_nd: float
    vel_cov_ee: float
    vel_cov_ed: float
    vel_cov_dd: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., itow: _Optional[int] = ..., version: _Optional[int] = ..., pos_cor_valid: bool = ..., vel_cor_valid: bool = ..., pos_cov_nn: _Optional[float] = ..., pos_cov_ne: _Optional[float] = ..., pos_cov_nd: _Optional[float] = ..., pos_cov_ee: _Optional[float] = ..., pos_cov_ed: _Optional[float] = ..., pos_cov_dd: _Optional[float] = ..., vel_cov_nn: _Optional[float] = ..., vel_cov_ne: _Optional[float] = ..., vel_cov_nd: _Optional[float] = ..., vel_cov_ee: _Optional[float] = ..., vel_cov_ed: _Optional[float] = ..., vel_cov_dd: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BidProposal(_message.Message):
    __slots__ = ("header", "fleet_name", "expected_robot_name", "prev_cost", "new_cost", "finish_time")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    PREV_COST_FIELD_NUMBER: _ClassVar[int]
    NEW_COST_FIELD_NUMBER: _ClassVar[int]
    FINISH_TIME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    fleet_name: str
    expected_robot_name: str
    prev_cost: float
    new_cost: float
    finish_time: _time_pb2.Time
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., fleet_name: _Optional[str] = ..., expected_robot_name: _Optional[str] = ..., prev_cost: _Optional[float] = ..., new_cost: _Optional[float] = ..., finish_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActiveMonitoringCase(_message.Message):
    __slots__ = ("header", "monitoring_case_1", "monitoring_case_2", "monitoring_case_3", "monitoring_case_4")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MONITORING_CASE_1_FIELD_NUMBER: _ClassVar[int]
    MONITORING_CASE_2_FIELD_NUMBER: _ClassVar[int]
    MONITORING_CASE_3_FIELD_NUMBER: _ClassVar[int]
    MONITORING_CASE_4_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    monitoring_case_1: int
    monitoring_case_2: int
    monitoring_case_3: int
    monitoring_case_4: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., monitoring_case_1: _Optional[int] = ..., monitoring_case_2: _Optional[int] = ..., monitoring_case_3: _Optional[int] = ..., monitoring_case_4: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UserDisplay(_message.Message):
    __slots__ = ("header", "ip", "battery", "entries", "selected_entry")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IP_FIELD_NUMBER: _ClassVar[int]
    BATTERY_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    SELECTED_ENTRY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ip: str
    battery: str
    entries: _containers.RepeatedScalarFieldContainer[str]
    selected_entry: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ip: _Optional[str] = ..., battery: _Optional[str] = ..., entries: _Optional[_Iterable[str]] = ..., selected_entry: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import space_pb2 as _space_pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import timespan_pb2 as _timespan_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Region(_message.Message):
    __slots__ = ("header", "map", "spaces", "timespan")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_FIELD_NUMBER: _ClassVar[int]
    SPACES_FIELD_NUMBER: _ClassVar[int]
    TIMESPAN_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map: str
    spaces: _containers.RepeatedCompositeFieldContainer[_space_pb2.Space]
    timespan: _timespan_pb2.Timespan
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map: _Optional[str] = ..., spaces: _Optional[_Iterable[_Union[_space_pb2.Space, _Mapping]]] = ..., timespan: _Optional[_Union[_timespan_pb2.Timespan, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marti_nav_msgs/msg/grid_map.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/jazzy/marti_nav_msgs/msg/grid_map.proto\x12-make87_messages_ros2.jazzy.marti_nav_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x36make87_messages_ros2/jazzy/sensor_msgs/msg/image.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xc6\x03\n\x07GridMap\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x45\n\x08top_left\x18\x02 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\x46\n\ttop_right\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12I\n\x0c\x62ottom_right\x18\x04 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12H\n\x0b\x62ottom_left\x18\x05 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12\x11\n\tmap_names\x18\x06 \x03(\t\x12\x43\n\x08map_data\x18\x07 \x03(\x0b\x32\x31.make87_messages_ros2.jazzy.sensor_msgs.msg.Imageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marti_nav_msgs.msg.grid_map_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRIDMAP']._serialized_start=280
  _globals['_GRIDMAP']._serialized_end=734
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mrpt_nav_interfaces/srv/get_pointmap_layer.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/mrpt_nav_interfaces/srv/get_pointmap_layer.proto\x12\x32make87_messages_ros2.jazzy.mrpt_nav_interfaces.srv\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\"-\n\x17GetPointmapLayerRequest\x12\x12\n\nlayer_name\x18\x01 \x01(\t\"r\n\x18GetPointmapLayerResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12G\n\x06points\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mrpt_nav_interfaces.srv.get_pointmap_layer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPOINTMAPLAYERREQUEST']._serialized_start=194
  _globals['_GETPOINTMAPLAYERREQUEST']._serialized_end=239
  _globals['_GETPOINTMAPLAYERRESPONSE']._serialized_start=241
  _globals['_GETPOINTMAPLAYERRESPONSE']._serialized_end=355
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/set_joint_trajectory.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.trajectory_msgs.msg import joint_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_trajectory__msgs_dot_msg_dot_joint__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/gazebo_msgs/srv/set_joint_trajectory.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a\x45make87_messages_ros2/jazzy/trajectory_msgs/msg/joint_trajectory.proto\"\x8b\x02\n\x19SetJointTrajectoryRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12Y\n\x10joint_trajectory\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.jazzy.trajectory_msgs.msg.JointTrajectory\x12\x46\n\nmodel_pose\x18\x03 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x16\n\x0eset_model_pose\x18\x04 \x01(\x08\x12\x1f\n\x17\x64isable_physics_updates\x18\x05 \x01(\x08\"E\n\x1aSetJointTrajectoryResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0estatus_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.set_joint_trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETJOINTTRAJECTORYREQUEST']._serialized_start=246
  _globals['_SETJOINTTRAJECTORYREQUEST']._serialized_end=513
  _globals['_SETJOINTTRAJECTORYRESPONSE']._serialized_start=515
  _globals['_SETJOINTTRAJECTORYRESPONSE']._serialized_end=584
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/game_controller_spl_interfaces/msg/rcgcd16.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.game_controller_spl_interfaces.msg import team_info15_pb2 as make87__messages__ros2_dot_jazzy_dot_game__controller__spl__interfaces_dot_msg_dot_team__info15__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/game_controller_spl_interfaces/msg/rcgcd16.proto\x12=make87_messages_ros2.jazzy.game_controller_spl_interfaces.msg\x1aOmake87_messages_ros2/jazzy/game_controller_spl_interfaces/msg/team_info15.proto\"\xd8\x02\n\x07RCGCD16\x12\x15\n\rpacket_number\x18\x01 \x01(\r\x12\x18\n\x10players_per_team\x18\x02 \x01(\r\x12\x19\n\x11\x63ompetition_phase\x18\x03 \x01(\r\x12\x18\n\x10\x63ompetition_type\x18\x04 \x01(\r\x12\x12\n\ngame_phase\x18\x05 \x01(\r\x12\r\n\x05state\x18\x06 \x01(\r\x12\x10\n\x08set_play\x18\x07 \x01(\r\x12\x12\n\nfirst_half\x18\x08 \x01(\r\x12\x14\n\x0ckicking_team\x18\t \x01(\r\x12\x16\n\x0esecs_remaining\x18\n \x01(\x05\x12\x16\n\x0esecondary_time\x18\x0b \x01(\x05\x12X\n\x05teams\x18\x0c \x03(\x0b\x32I.make87_messages_ros2.jazzy.game_controller_spl_interfaces.msg.TeamInfo15b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.game_controller_spl_interfaces.msg.rcgcd16_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RCGCD16']._serialized_start=224
  _globals['_RCGCD16']._serialized_end=568
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_perception_msgs/msg/traffic_light_group.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import traffic_light_element_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__perception__msgs_dot_msg_dot_traffic__light__element__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/jazzy/autoware_perception_msgs/msg/traffic_light_group.proto\x12\x37make87_messages_ros2.jazzy.autoware_perception_msgs.msg\x1aSmake87_messages_ros2/jazzy/autoware_perception_msgs/msg/traffic_light_element.proto\"\x93\x01\n\x11TrafficLightGroup\x12\x1e\n\x16traffic_light_group_id\x18\x01 \x01(\x03\x12^\n\x08\x65lements\x18\x02 \x03(\x0b\x32L.make87_messages_ros2.jazzy.autoware_perception_msgs.msg.TrafficLightElementb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_perception_msgs.msg.traffic_light_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRAFFICLIGHTGROUP']._serialized_start=228
  _globals['_TRAFFICLIGHTGROUP']._serialized_end=375
# @@protoc_insertion_point(module_scope)
